==> jboss-eap-7.4.4-core-src.zip: jboss-eap-7.4-core-src/host-controller/src/test/java/org/jboss/as/domain/controller/operations/OrderedChildResourceNonIndexedAddSyncModelTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.domain.controller.operations;


/**
 * Tests a single level of ordered children in the scenario where the slave model does not support indexed adds, and we need to remove and re-add
 * all ordered children to maintain the order.
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class OrderedChildResourceNonIndexedAddSyncModelTestCase extends OrderedChildResourceSyncModelTestCase {

    public OrderedChildResourceNonIndexedAddSyncModelTestCase() {
        super(false);
    }


}

==> jboss-eap-8.0.3-core-src.zip: jboss-eap-8.0-core-src/host-controller/src/test/java/org/jboss/as/domain/controller/operations/OrderedChildResourceNonIndexedAddSyncModelTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.domain.controller.operations;


/**
 * Tests a single level of ordered children in the scenario where the secondary model does not support indexed adds, and we need to remove and re-add
 * all ordered children to maintain the order.
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class OrderedChildResourceNonIndexedAddSyncModelTestCase extends OrderedChildResourceSyncModelTestCase {

    public OrderedChildResourceNonIndexedAddSyncModelTestCase() {
        super(false);
    }


}
